#
# spec file for package python-strictyaml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-strictyaml
Version:        1.7.3
Release:        2.5
Summary:        Strict, typed YAML parser
License:        MIT
URL:            https://hitchdev.com/strictyaml
Source:         https://files.pythonhosted.org/packages/source/s/strictyaml/strictyaml-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.6.0
BuildArch:      noarch
# SECTION test requirements
# BuildRequires:  %{python_module pytest}
# BuildRequires:  %{python_module python-dateutil >= 2.6.0}
# /SECTION
%python_subpackages

%description
StrictYAML is a type-safe YAML parser that parses and validates a
restricted subset of the YAML specification.

Priorities:

 * No parsing of hard to read and insecure features of YAML like the
   Norway problem.
 * Strict validation of markup and straightforward type casting.
 * Acting as a near-drop in replacement for pyyaml, ruamel.yaml or poyo.
 * Comment preservation across a read-write cycle
 * Speed is not a key concern

%prep
%setup -q -n strictyaml-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#%%check
# Not feasible due to extensive number of test dependencies
# and they are not suited for rpmbuild
# https://github.com/hitchdev/hitchkey/issues/2

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/strictyaml
%{python_sitelib}/strictyaml-%{version}.dist-info

%changelog
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.3:
  * REFACTOR : Fix pipeline.
  * TOOLING : Improvements to pyenv multi-environment tester.
  * FEATURE : Upgraded package to use pyproject.toml files
  * REFACTOR : Fixed linter errors.
  * TOOLING : Build wheel and sdist that both work.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.6.2
  No relevant code changes.
  see details changelog: https://hitchdev.com/strictyaml/changelog/#latest
* Wed Mar  9 2022 Michael Ströder <michael@stroeder.com>
- update to 1.6.1
  too many changes to be listed here
  see detailed changelog: https://hitchdev.com/strictyaml/changelog/
* Tue Aug  3 2021 Markéta Machová <mmachova@suse.com>
- update to 1.4.4
  * Add support for NaN and infinity representations
  * Optional keys in mappings and set value to None
  * Support underscores in int and decimal
  * NullNone - parse 'null' as None like YAML 1.2 does.
  * Bundle last propertly working ruamel.yaml version in with strictyaml.
* Tue Mar 17 2020 pgajdos@suse.com
- version update to 1.0.6
  * BUGFIX : Fix accidental python 2 breakage.
  * BUGFIX : Accidental misrecognition of boolean values as numbers - cause of #85.
  * BUGFIX : Fix for #86 - handle changing multiline strings.
  * BUGFIX: handle deprecated collections import in the parser (#82)
* Thu Oct 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.5:
  * BUGFIX : Fixed python 2 bug introduced when fixing #72.
  * FEATURE : Include tests / stories in package.
  * BUG: issue #72. Now setitem uses schema.
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Expand %%description.
* Tue Sep 10 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.0.3
